searchData={"items":[{"type":"module","title":"ReqS3","doc":"`Req` plugin for [Amazon S3](https://aws.amazon.com/s3) and S3 API-compatible services.\n\nReqS3 handles a custom `s3://` url scheme that supports two endpoints:\n\n```text\ns3://         # list bucket items\ns3:// /  # get item content\n```","ref":"ReqS3.html"},{"type":"module","title":"Examples - ReqS3","doc":"iex> req = Req.new() |> ReqS3.attach()\n    iex> Req.get!(req, url: \"s3://ossci-datasets\").body\n    %{\n      \"ListBucketResult\" => %{\n        \"Contents\" => [\n          %{\"Key\" => \"mnist/\", ...},\n          %{\"Key\" => \"mnist/t10k-images-idx3-ubyte.gz\", ...},\n          ...\n        ],\n        \"Name\" => \"ossci-datasets\",\n        ...\n      }\n    }\n\n    iex> req = Req.new() |> ReqS3.attach()\n    iex> body = Req.get!(req, url: \"s3://ossci-datasets/mnist/t10k-images-idx3-ubyte.gz\").body\n    iex> <<_::32, n_images::32, n_rows::32, n_cols::32, _body::binary>> = body\n    iex> {n_images, n_rows, n_cols}\n    {10_000, 28, 28}","ref":"ReqS3.html#module-examples"},{"type":"module","title":"Pre-signing - ReqS3","doc":"See `presign_url/1` and `presign_form/1`.","ref":"ReqS3.html#module-pre-signing"},{"type":"function","title":"ReqS3.attach/2","doc":"Attaches the plugin.","ref":"ReqS3.html#attach/2"},{"type":"function","title":"ReqS3.presign_form/1","doc":"Returns presigned form for upload.","ref":"ReqS3.html#presign_form/1"},{"type":"function","title":"Options - ReqS3.presign_form/1","doc":"* `:access_key_id` - the access key id.\n\n  * `:secret_access_key` - the secret access key.\n\n  * `:region` - the S3 region, defaults to `\"us-east-1\"`.\n\n  * `:bucket` - the S3 bucket.\n\n  * `:key` - the S3 bucket key.\n\n  * `:content_type` - if set, the content-type of the uploaded object.\n\n  * `:max_size` - if set, the maximum size of the uploaded object.\n\n  * `:expires_in` - the time in milliseconds before the signed upload expires. Defaults to 1h\n    (`60 * 60 * 1000` milliseconds).\n\n  * `:datetime` - the request datetime, defaults to `DateTime.utc_now(:second)`.","ref":"ReqS3.html#presign_form/1-options"},{"type":"function","title":"Examples - ReqS3.presign_form/1","doc":"iex> options = [\n    ...>   access_key_id: System.fetch_env!(\"AWS_ACCESS_KEY_ID\"),\n    ...>   secret_access_key: System.fetch_env!(\"AWS_SECRET_ACCESS_KEY\"),\n    ...>   bucket: \"bucket1\",\n    ...>   key: \"key1\",\n    ...>   expires_in: :timer.hours(1)\n    ...> ]\n    iex> %{url: url, fields: fields} = ReqS3.presign_form(options)\n    iex> url\n    \"https://bucket1.s3.amazonaws.com\"\n    iex> fields\n    %{\n      \"key\" => \"key1\",\n      \"policy\" => \"eyJjb25kaXRpb25z...ifQ==\",\n      \"x-amz-algorithm\" => \"AWS4-HMAC-SHA256\",\n      \"x-amz-credential\" => \"AKIA.../20240528/us-east-1/s3/aws4_request\",\n      \"x-amz-date\" => \"20240528T105226Z\",\n      \"x-amz-server-side-encryption\" => \"AES256\",\n      \"x-amz-signature\" => \"465315d202fbb2ce081f79fca755a958a18ff68d253e6d2a611ca4b2292d8925\"\n    }","ref":"ReqS3.html#presign_form/1-examples"},{"type":"function","title":"ReqS3.presign_url/1","doc":"Returns a presigned URL for fetching bucket object contents.","ref":"ReqS3.html#presign_url/1"},{"type":"function","title":"Options - ReqS3.presign_url/1","doc":"* `:access_key_id` - the AWS access key id.\n\n  * `:secret_access_key` - the AWS secret access key.\n\n  * `:region` - if set, AWS region. Defaults to `\"us-east-1\"`.\n\n  * `:url` - the URL to presign, for example: `\"https://bucket.s3.amazonaws.com\"` or `s3://bucket`.\n\n     Instead of passing the `:url` option, you can also pass `:bucket` and `:key` options\n     which will generate a `https://{bucket}.s3.amazonaws.com/{key}` url.","ref":"ReqS3.html#presign_url/1-options"},{"type":"function","title":"Examples - ReqS3.presign_url/1","doc":"iex> options = [\n    ...>   access_key_id: System.fetch_env!(\"AWS_ACCESS_KEY_ID\"),\n    ...>   secret_access_key: System.fetch_env!(\"AWS_SECRET_ACCESS_KEY\"),\n    ...> ]\n    iex> req = Req.new() |> ReqS3.attach(aws_sigv4: options)\n    iex> %{status: 200} = Req.put!(req, url: \"s3://wojtekmach-test/key1\", body: \"Hello, World!\")\n    iex> url = ReqS3.presign_url([url: \"s3://wojtekmach-test/key1\"] ++ options)\n    iex> \"https://wojtekmach-test.s3.amazonaws.com/key1?X-Amz-Algorithm=AWS4-HMAC\" <> _ = url\n    iex> %{status: 200, body: body} = Req.get!(url)\n    iex> body\n    \"Hello, World!\"","ref":"ReqS3.html#presign_url/1-examples"},{"type":"extras","title":"ReqS3","doc":"# ReqS3\n\n[Req](https://github.com/wojtekmach/req) plugin for [Amazon S3](https://aws.amazon.com/s3/) and S3-compatible services.\n\nReqS3 handles a custom `s3://` url scheme that supports these URLs:\n\n```text\ns3://         # GET bucket items list\ns3:// /  # GET/PUT bucket item\n```","ref":"readme.html"},{"type":"extras","title":"Usage - ReqS3","doc":"```elixir\nMix.install([\n  {:req, \"~> 0.5.0\"},\n  {:req_s3, \"~> 0.2.0\"}\n])\n\nreq = Req.new() |> ReqS3.attach()\n\nReq.get!(req, url: \"s3://ossci-datasets\").body\n#=>\n# %{\n#   \"ListBucketResult\" => %{\n#     \"Contents\" => [\n#       %{\"Key\" => \"mnist/\", ...},\n#       %{\"Key\" => \"mnist/t10k-images-idx3-ubyte.gz\", ...},\n#       ...\n#     ],\n#     \"Name\" => \"ossci-datasets\",\n#     ...\n#   }\n# }\n\nbody = Req.get!(req, url: \"s3://ossci-datasets/mnist/t10k-images-idx3-ubyte.gz\").body\n<<_::32, n_images::32, n_rows::32, n_cols::32, _body::binary>> = body\n{n_images, n_rows, n_cols}\n#=> {10_000, 28, 28}\n```\n\nReqS3 can be also used to presign URLs:\n\n```elixir\noptions = [\n  access_key_id: System.fetch_env!(\"AWS_ACCESS_KEY_ID\"),\n  secret_access_key: System.fetch_env!(\"AWS_SECRET_ACCESS_KEY\")\n]\n\nreq = Req.new() |> ReqS3.attach(aws_sigv4: options)\n%{status: 200} = Req.put!(req, url: \"s3://bucket1/key1\", body: \"Hello, World!\")\n\npresigned_url = ReqS3.presign_url([url: \"s3://bucket1/key1\"] ++ options)\n#=> \"https://s3.amazonaws.com/bucket1/key1?X-Amz-Algorithm=AWS4-HMAC-SHA256&...\"\n\nReq.get!(presigned_url).body\n#=> \"Hello, World!\"\n```\n\nand form uploads:\n\n```elixir\nform = ReqS3.presign_form([bucket: \"bucket1\", key: \"key1\"] ++ options)\nReq.post!(form.url, form_multipart: [file: \"Hello, World!\"] ++ form.fields)\n#=> \"Hello, World!\"\n```","ref":"readme.html#usage"},{"type":"extras","title":"TODO - ReqS3","doc":"* Add Phoenix Playground example.","ref":"readme.html#todo"},{"type":"extras","title":"License - ReqS3","doc":"Copyright (c) 2021 Wojtek Mach\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"CHANGELOG","doc":"# CHANGELOG","ref":"changelog.html"},{"type":"extras","title":"v0.2.0 (2024-07-18) - CHANGELOG","doc":"* Support Req v0.5.\n\n  * Change decoded response for `s3://{bucket}` endpoint. Instead of listing\n    just object keys, return decoded XML response.\n\n  * Add [`ReqS3.presign_url/1`].\n\n  * Add [`ReqS3.presign_form/1`].","ref":"changelog.html#v0-2-0-2024-07-18"},{"type":"extras","title":"v0.1.1 (2023-09-01) - CHANGELOG","doc":"* Support Req v0.4.","ref":"changelog.html#v0-1-1-2023-09-01"},{"type":"extras","title":"v0.1.0 (2022-08-24) - CHANGELOG","doc":"* Initial release\n\n[`ReqS3.presign_url/1`]: https://hexdocs.pm/req_s3/ReqS3.html#presign_url/1\n[`ReqS3.presign_form/1`]: https://hexdocs.pm/req_s3/ReqS3.html#presign_form/1","ref":"changelog.html#v0-1-0-2022-08-24"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}